from sqlalchemy import Column, Integer, String, Boolean, DateTime
from sqlalchemy.sql import func
from sqlalchemy.orm import relationship # <-- NOUVELLE IMPORTATION
from core.database import Base

class User(Base):
    __tablename__ = "users"

    id = Column(Integer, primary_key=True, index=True)
    email = Column(String, unique=True, index=True, nullable=False)
    hashed_password = Column(String, nullable=False)
    name = Column(String, nullable=True)
    is_active = Column(Boolean, default=True)
    created_at = Column(DateTime, default=func.now())
    updated_at = Column(DateTime, default=func.now(), onupdate=func.now())

    # Relation avec les documents de l'utilisateur
    documents = relationship("Document", back_populates="owner") # <-- NOUVELLE LIGNE
    ai_interactions = relationship("AiInteraction", back_populates="user") # <-- NOUVELLE LIGNE

    def __repr__(self):
        return f"<User(email='{self.email}', id={self.id})>"